==> cometchat-3.0.5.tar.gz: lib/Builders/blocked_users_request.dart <==
import 'package:cometchat/Exception/CometChatException.dart';
import 'package:cometchat/models/user.dart';
import 'package:cometchat/utils/constants.dart';
import 'package:flutter/services.dart';

class BlockedUsersRequest {
  static final String directionBlockedByMe = "blockedByMe";
  static final String directionHasBlockedMe = "hasBlockedMe";
  static final String directionBoth = "both";

  static final int maxLimit = 100;
  static final int defaultLimit = 30;

  final int? limit;
  final int? token;
  final String? searchKeyword;
  final String? direction;
  bool? init;

  BlockedUsersRequest._builder(BlockedUsersRequestBuilder builder)
      : limit = builder.limit,
        token = builder.token,
        searchKeyword = builder.searchKeyword,
        direction = builder.direction,
        init = true;

  ///fetch the list of Users that logged-in user have blocked.
  ///
  ///method could throw [PlatformException] with error codes specifying the cause
  ///
  /// See also [Android Documentation](https://www.cometchat.com/docs/android-chat-sdk/users-block-users) [IOS Documentation](https://www.cometchat.com/docs/ios-chat-sdk/users-block-users)
  Future<List<User>> fetchNext(
      {required Function(List<User> userList)? onSuccess,
      required Function(CometChatException excep)? onError}) async {
    try {
      final result = await channel.invokeMethod('fetchBlockedUsers', {
        'limit': this.limit,
        'searchKeyword': this.searchKeyword,
        'direction': this.direction,
        'init': this.init,
      });
      //final List<User> res = result.map<User>((e) => User.fromMap(e)).toList();
      final List<User> res = [];
      if (result != null) {
        for (var _obj in result) {
          try {
            res.add(User.fromMap(_obj));
          } catch (_) {}
        }
      }

      if (onSuccess != null) {
        onSuccess(res);
      }
      this.init = false;
      return res;
    } on PlatformException catch (platformException) {
      if (onError != null) {
        onError(CometChatException(platformException.code,
            platformException.details, platformException.message));
      }
    } catch (e) {
      throw e;
    }
    return [];
  }
}

class BlockedUsersRequestBuilder {
  int? limit;
  int? token;
  String? searchKeyword;
  String? direction;

  BlockedUsersRequestBuilder();

  BlockedUsersRequest build() {
    return BlockedUsersRequest._builder(this);
  }
}

==> cometchat-3.0.7.tar.gz: lib/Builders/blocked_users_request.dart <==
import 'package:cometchat/Exception/CometChatException.dart';
import 'package:cometchat/models/user.dart';
import 'package:cometchat/utils/constants.dart';
import 'package:flutter/services.dart';

class BlockedUsersRequest {
  static final String directionBlockedByMe = "blockedByMe";
  static final String directionHasBlockedMe = "hasBlockedMe";
  static final String directionBoth = "both";

  static final int maxLimit = 100;
  static final int defaultLimit = 30;

  final int? limit;
  final int? token;
  final String? searchKeyword;
  final String? direction;
  String? key;

  BlockedUsersRequest._builder(BlockedUsersRequestBuilder builder)
      : limit = builder.limit,
        token = builder.token,
        searchKeyword = builder.searchKeyword,
        direction = builder.direction;

  ///fetch the list of Users that logged-in user have blocked.
  ///
  ///method could throw [PlatformException] with error codes specifying the cause
  ///
  /// See also [Android Documentation](https://www.cometchat.com/docs/android-chat-sdk/users-block-users) [IOS Documentation](https://www.cometchat.com/docs/ios-chat-sdk/users-block-users)
  Future<List<User>> fetchNext(
      {required Function(List<User> userList)? onSuccess,
      required Function(CometChatException excep)? onError}) async {
    try {
      final result = await channel.invokeMethod('fetchBlockedUsers', {
        'limit': this.limit,
        'searchKeyword': this.searchKeyword,
        'direction': this.direction,
        'key': this.key
      });
      final List<User> res = [];
      if (result != null) {
        key = result["key"];

        if (result["list"] != null) {
          for (var _obj in result["list"]) {
            try {
              res.add(User.fromMap(_obj));
            } catch (_) {}
          }
        }
      }
      print("key is ${key}");

      // if (result != null) {
      //   for (var _obj in result) {
      //     try {
      //       res.add(User.fromMap(_obj));
      //     } catch (_) {}
      //   }
      // }

      if (onSuccess != null) {
        onSuccess(res);
      }
      return res;
    } on PlatformException catch (platformException) {
      if (onError != null) {
        onError(CometChatException(platformException.code,
            platformException.details, platformException.message));
      }
    } catch (e) {
      throw e;
    }
    return [];
  }
}

class BlockedUsersRequestBuilder {
  int? limit;
  int? token;
  String? searchKeyword;
  String? direction;

  BlockedUsersRequestBuilder();

  BlockedUsersRequest build() {
    return BlockedUsersRequest._builder(this);
  }
}
